pub struct BudgetRulesReport(pub DiagnosticsReport);Expand description
Report returned by the budget native rule check.
Wraps the DiagnosticsReport produced by the budget service so that it
can be formatted standalone (as text) or converted to a DiagnosticsReport
for the rules engine.
Tuple Fields
0: DiagnosticsReportTrait Implementations
Sourceimpl Debug for BudgetRulesReport
impl Debug for BudgetRulesReport
Sourceimpl From<BudgetRulesReport> for DiagnosticsReport
impl From<BudgetRulesReport> for DiagnosticsReport
Sourcefn from(report: BudgetRulesReport) -> Self
fn from(report: BudgetRulesReport) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for BudgetRulesReport
impl JsonSchema for BudgetRulesReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OutputFormatter for BudgetRulesReport
impl OutputFormatter for BudgetRulesReport
Sourcefn format_text(&self) -> String
fn format_text(&self) -> String
Format as minimal text (LLM-optimized, default).
Sourcefn format_pretty(&self) -> String
fn format_pretty(&self) -> String
Format as pretty text (human-friendly with colors).
Default implementation falls back to format_text().