Structs
- Missing
Summary Report - Report produced by the
missing-summarynative rule check. - Stale
Summary Report - Report produced by the
stale-summarynative rule check.
Constants
- DEFAULT_
FILENAMES - Default filenames checked by
stale-summaryandmissing-summarywhen none are configured.
Functions
- build_
missing_ summary_ report - Build a
MissingSummaryReportby walking the repository underrootand checking each directory for a doc file that is present (committed at least once). - build_
stale_ summary_ report - Build a
StaleSummaryReportby walking the repository underrootand checking each directory for a doc file that is up-to-date.