Native rule checks for normalize.
Implements stale-summary, check-refs, stale-docs, check-examples, ratchet, budget,
long-file, high-complexity, long-function, high-fan-out, and high-fan-in as pure
Rust checks. These are the “native engine” checks invoked by
normalize rules run --engine native.
Re-exports
pub use cache::FileRule;pub use cache::FindingsCache;pub use cache::file_mtime_nanos as cache_file_mtime_nanos;pub use cache::run_file_rule;pub use boundary_violations::Boundary;pub use boundary_violations::BoundaryViolationsConfig;pub use boundary_violations::build_boundary_violations_report;pub use boundary_violations::parse_boundary;pub use budget::BudgetRulesReport;pub use budget::build_budget_report;pub use check_examples::build_check_examples_report;pub use check_refs::build_check_refs_report;pub use dead_parameter::build_dead_parameter_report;pub use high_complexity::build_high_complexity_report;pub use high_fan_in::build_high_fan_in_report;pub use high_fan_out::build_high_fan_out_report;pub use long_file::build_long_file_report;pub use long_function::build_long_function_report;pub use ratchet::RatchetRulesReport;pub use ratchet::build_ratchet_report;pub use stale_doc::StaleDocConfig;pub use stale_doc::build_stale_doc_report;pub use stale_docs::build_stale_docs_report;pub use stale_summary::build_missing_summary_report;pub use stale_summary::build_stale_summary_report;
Modules
- boundary_
violations boundary-violationsnative rule — flags cross-boundary imports.- budget
- Native rule integration for the budget system.
- cache
- SQLite-backed per-file findings cache.
- check_
examples - Validate example references in documentation
- check_
refs - Check documentation references for broken links
- dead_
parameter dead-parameternative rule — flags function parameters never referenced in the function body.- high_
complexity high-complexitynative rule — flags functions exceeding a cyclomatic complexity threshold.- high_
fan_ in high-fan-innative rule — flags files that are imported by too many other files.- high_
fan_ out high-fan-outnative rule — flags files that import from too many other files.- long_
file long-filenative rule — flags source files exceeding a line count threshold.- long_
function long-functionnative rule — flags functions exceeding a line count threshold.- ratchet
- Native rule integration for the ratchet system.
- stale_
doc stale-docnative rule — detects documentation files that are likely stale because strongly co-changed code files have been updated more recently.- stale_
docs - Find stale documentation where covered code has changed
- stale_
summary - walk
Structs
- Native
Rule Descriptor - Static descriptor for a native rule’s default metadata.
Constants
- NATIVE_
RULES - All native rules with their default metadata.