pub fn build_budget_report(root: &Path) -> BudgetRulesReportExpand description
Build a BudgetRulesReport from the budget check for use in normalize rules run.
Called by the native rules engine. Returns an empty report if no budget file exists or all limits are within bounds.