Module stale_summary

Module stale_summary 

Structs

MissingSummaryReport
Report produced by the missing-summary native rule check.
StaleSummaryReport
Report produced by the stale-summary native rule check.

Constants

DEFAULT_FILENAMES
Default filenames checked by stale-summary and missing-summary when none are configured.

Functions

build_missing_summary_report
Build a MissingSummaryReport by walking the repository under root and checking each directory for a doc file that is present (committed at least once).
build_stale_summary_report
Build a StaleSummaryReport by walking the repository under root and checking each directory for a doc file that is up-to-date.